summaryrefslogtreecommitdiff
path: root/nuttx/include/net/uip/uip.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-06-16 23:23:31 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-06-16 23:23:31 +0000
commit1bb56fb39d8db0c9a419818f82fa7e517cad55bc (patch)
treec6d5b6911e4ae7c85e4aa0b2f7a07c387c618d38 /nuttx/include/net/uip/uip.h
parent731994d0383c636e43644c3dc91b91b15745b345 (diff)
downloadpx4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.tar.gz
px4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.tar.bz2
px4-nuttx-1bb56fb39d8db0c9a419818f82fa7e517cad55bc.zip
Reserved word 'private' in C header files is a problem for C++
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1890 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/net/uip/uip.h')
-rw-r--r--nuttx/include/net/uip/uip.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/include/net/uip/uip.h b/nuttx/include/net/uip/uip.h
index 640ac07fc..0482b9099 100644
--- a/nuttx/include/net/uip/uip.h
+++ b/nuttx/include/net/uip/uip.h
@@ -5,7 +5,7 @@
* are used by uIP programs as well as internal uIP structures and function
* declarations.
*
- * Copyright (C) 2007, 2008, 2009 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2007-2009 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <spudmonkey@racsa.co.cr>
*
* This logic was leveraged from uIP which also has a BSD-style license:
@@ -203,7 +203,7 @@ struct uip_ip_hdr
* flink - Supports a singly linked list
* event - Provides the address of the callback function entry point.
* pvconn is a pointer to one of struct uip_conn or struct uip_udp_conn.
* private - Holds a reference to application specific data that will
* provided
* flags - Set by the application to inform the uIP layer which flags
* are and are not handled by the callback.
@@ -213,8 +213,8 @@ struct uip_driver_s; /* Forward reference */
struct uip_callback_s
{
FAR struct uip_callback_s *flink;
- uint16 (*event)(struct uip_driver_s *dev, void *pvconn, void *pvprivate, uint16 flags);
- void *private;
+ uint16 (*event)(struct uip_driver_s *dev, void *pvconn, void *pvpriv, uint16 flags);
+ void *priv;
uint16 flags;
};
@@ -203,7 +203,7 @@ struct uip_ip_hdr
* event - Provides the address of the callback function entry point.
* pvconn is a pointer to one of struct uip_conn or struct uip_udp_conn.
- * private - Holds a reference to application specific data that will
+ * priv - Holds a reference to application specific data that will
* provided
* flags - Set by the application to inform the uIP layer which flags